@@ -16,6 +16,7 @@ def log_test():
     logger = logging.getLogger()
     for i in range(10000):
         logger.info("1111111111111111")
+        logger.debug("222222222222222222")
         time.sleep(1)
 
 
@@ -24,5 +25,10 @@ def log_test2():
     logger.report("123456")
 
 
+def log_test3():
+    logger = logging.getLogger()
+    logger.error('123')
+
+
 if __name__ == '__main__':
     log_test()
